package de.opalpiraten.scenepainter.sys;
import java.net.URL;
import java.io.*;
import java.util.*;
import javax.swing.*;
import com.samskivert.util.StringUtil;

/**
 * A NenyaDescriptor, that gets information from a configfile
 */
public class ConfiguredDescriptor extends NenyaDescriptor {

  /**
   * The path (relative to the classpath), the configfiles are expected in
   */
  public static final String CFGDIR = "resources/nenyacfg";
  
  /**
   * The file containing the indexlist in the configdir
   */
  public static final String INDEX = "index.lst";
  
  /**
   * Construct a new descriptor using a configfile found in the resourcepath
   * @param base base directory
   * @param name name of a resource, that can be found in the 
   * "resources/nenyacfg" path
   * @throws IllegalArgumentException, if the descriptor cannot be build
   * from the given basedir and configfile.
   */
  public ConfiguredDescriptor(File base, String name) throws IllegalArgumentException {
    try {
      InputStream ins = ClassLoader.getSystemResourceAsStream(CFGDIR+"/"+name);
      Properties props = new Properties();
      props.load(ins);
      product = props.get("nenya.product").toString();
      root = props.get("nenya.prefix").toString();
      rsrcdir = new File(base,root).getAbsolutePath();
      manager = props.get("nenya.manager").toString();
      tilesets = props.get("nenya.tilebundle").toString();;
      components = props.get("nenya.componentbundle").toString();
      jars = new URL[Integer.parseInt(props.get("nenya.extralibs").toString())];
      for (int i =0;i<jars.length;i++) {
        String tmp = props.get("nenya.extralibs."+i).toString();
        if (!"/".equals(File.separator)) {                                      
          tmp = StringUtil.replace(tmp, "/", File.separator);               
        }
        jars[i]=new File(base,tmp).toURL();
      }
      
      String testname = props.get("nenya.checkfile").toString();
      if (testname!=null) {
        if (!new File(base,testname).exists()) throw new IllegalArgumentException();
      }
      
      if (tilesets.equals("")) tilesets =null;
      if (components.equals("")) components =null;
    }
    catch (Exception e) {
      throw new IllegalArgumentException();
    }
  }
  
  /**
   * Automagically create a Descriptor matching a certain directory
   * @param base the base directory, a matching descriptor is desired for
   * @return either a descriptor, which the nenyabrowser can use for
   * accessing the submitted directory or null.
   */
  public static ConfiguredDescriptor getDescriptor(File base) {
    ConfiguredDescriptor ret = null;
    String[] cfg = new String[0];
    try {
      InputStream ins = ClassLoader.getSystemResourceAsStream(CFGDIR+"/"+INDEX);
      Properties props = new Properties();
      props.load(ins);
      cfg = props.get("cfgfiles").toString().split(" *, *");
    }
    catch (Exception e) {
      e.printStackTrace();
    }
    
    
    for(int i=0;i<cfg.length;i++) {
      try {
        ret = new ConfiguredDescriptor(base,cfg[i]);
        break; // Success -> break the loop to return
      }
      catch (Exception e) {}
    }
    
    return ret;
  }
}
